@@ -50,6 +50,8 @@ exports.serve = function (nylon_path, port) {
             if (code != 255) {
                 cluster.fork();
                 logger.info('worker ' + worker.process.pid + ' died');
+            }else{
+                process.exit(0);
             }
 
         });
